"use strict";
exports.__esModule = true;
var parser_util_1 = require("./parser.util");
describe('parser.util test', function () {
    describe('splitModuleType', function () {
        it('splitModuleType is function', function () {
            expect(parser_util_1.splitModuleType).toBeInstanceOf(Function);
        });
        it('javascript 依赖', function () {
            expect(parser_util_1.splitModuleType('base/util')).toEqual([
                'javascript', 'base/util'
            ]);
        });
        it('regular 依赖', function () {
            expect(parser_util_1.splitModuleType('regular!./tmp.html')).toEqual([
                'regular', './tmp.html'
            ]);
            expect(parser_util_1.splitModuleType('REGULAR!./tmp.html')).toEqual([
                'regular', './tmp.html'
            ]);
            expect(parser_util_1.splitModuleType('Regular!./tmp.html')).toEqual([
                'regular', './tmp.html'
            ]);
        });
        it('css/html 依赖', function () {
            expect(parser_util_1.splitModuleType('text!./tmp.html')).toEqual([
                'text', './tmp.html'
            ]);
            expect(parser_util_1.splitModuleType('TEXT!/tmp.html')).toEqual([
                'text', '/tmp.html'
            ]);
            expect(parser_util_1.splitModuleType('Text!{pro}tmp.html')).toEqual([
                'text', '{pro}tmp.html'
            ]);
        });
        it('json 依赖', function () {
            expect(parser_util_1.splitModuleType('json!./tmp.json')).toEqual([
                'json', './tmp.json'
            ]);
            expect(parser_util_1.splitModuleType('JSON!/tmp.json')).toEqual([
                'json', '/tmp.json'
            ]);
            expect(parser_util_1.splitModuleType('Json!{pro}tmp.json')).toEqual([
                'json', '{pro}tmp.json'
            ]);
        });
    });
    describe('normalize', function () {
        function _normalize(source) {
            return parser_util_1.normalize(source, {
                alias: {
                    pro: 'src/javascript'
                },
                isNejCode: true
            });
        }
        it('nej 内部依赖', function () {
            expect(_normalize('base/util')).toEqual('base/util.js');
            expect(_normalize('{platform}element/element.js')).toEqual('platform/element/element.js');
        });
        it('绝对路径, 直接返回', function () {
            expect(_normalize('/base/util.js')).toEqual('/base/util.js');
        });
        it('相对路径, 直接返回', function () {
            expect(_normalize('./base/util.js')).toEqual('./base/util.js');
        });
        it('使用 {} 语法的 alias', function () {
            expect(_normalize('{pro}global/util.js')).toEqual('src/javascript/global/util.js');
        });
        it('没使用 {} 语法的 alias', function () {
            expect(_normalize('pro/global/util')).toEqual('src/javascript/global/util.js');
        });
        it('未匹配到 alias', function () {
            expect(_normalize('common/global/util')).toEqual('common/global/util.js');
            expect(_normalize('{common}global/util')).toEqual('common/global/util.js');
        });
    });
    describe('analyzeDependence', function () {
        var options = {
            alias: {
                pro: 'src/javascript'
            },
            isNejCode: true
        };
        it('analyzeDependence is function', function () {
            expect(parser_util_1.analyzeDependence).toBeInstanceOf(Function);
        });
        it('解析相对路径', function () {
            expect(parser_util_1.analyzeDependence('./base/util.js', 'util', options)).toEqual({
                source: './base/util.js',
                name: 'util',
                rawSource: './base/util.js',
                moduleType: 'javascript'
            });
            expect(parser_util_1.analyzeDependence('../base/util.js', 'util', options)).toEqual({
                source: '../base/util.js',
                name: 'util',
                rawSource: '../base/util.js',
                moduleType: 'javascript'
            });
            expect(parser_util_1.analyzeDependence('regular!./template/tpl.html', 'tpl', options)).toEqual({
                source: './template/tpl.html',
                name: 'tpl',
                rawSource: 'regular!./template/tpl.html',
                moduleType: 'regular'
            });
            expect(parser_util_1.analyzeDependence('text!./template/styles.css', 'styles', options)).toEqual({
                source: './template/styles.css',
                name: 'styles',
                rawSource: 'text!./template/styles.css',
                moduleType: 'text'
            });
            expect(parser_util_1.analyzeDependence('json!../template/data.json', 'data', options)).toEqual({
                source: '../template/data.json',
                name: 'data',
                rawSource: 'json!../template/data.json',
                moduleType: 'json'
            });
        });
        it('解析绝对路径', function () {
            expect(parser_util_1.analyzeDependence('/base/util.js', 'util', options)).toEqual({
                source: '/base/util.js',
                name: 'util',
                rawSource: '/base/util.js',
                moduleType: 'javascript'
            });
            expect(parser_util_1.analyzeDependence('regular!/template/tpl.html', 'tpl', options)).toEqual({
                source: '/template/tpl.html',
                name: 'tpl',
                rawSource: 'regular!/template/tpl.html',
                moduleType: 'regular'
            });
            expect(parser_util_1.analyzeDependence('text!/template/styles.css', 'styles', options)).toEqual({
                source: '/template/styles.css',
                name: 'styles',
                rawSource: 'text!/template/styles.css',
                moduleType: 'text'
            });
            expect(parser_util_1.analyzeDependence('json!/template/data.json', 'data', options)).toEqual({
                source: '/template/data.json',
                name: 'data',
                rawSource: 'json!/template/data.json',
                moduleType: 'json'
            });
        });
        it('解析nej module', function () {
            expect(parser_util_1.analyzeDependence('base/util', '_u', options)).toEqual({
                source: 'base/util.js',
                name: '_u',
                rawSource: 'base/util',
                moduleType: 'javascript'
            });
            expect(parser_util_1.analyzeDependence('ui/form/form', '_f', options)).toEqual({
                source: 'ui/form/form.js',
                name: '_f',
                rawSource: 'ui/form/form',
                moduleType: 'javascript'
            });
            expect(parser_util_1.analyzeDependence('platform/element/element', '_e', options)).toEqual({
                source: 'platform/element/element.js',
                name: '_e',
                rawSource: 'platform/element/element',
                moduleType: 'javascript'
            });
            expect(parser_util_1.analyzeDependence('{base}util', '_u', options)).toEqual({
                source: 'base/util.js',
                name: '_u',
                rawSource: '{base}util',
                moduleType: 'javascript'
            });
            expect(parser_util_1.analyzeDependence('{ui}form/form', '_f', options)).toEqual({
                source: 'ui/form/form.js',
                name: '_f',
                rawSource: '{ui}form/form',
                moduleType: 'javascript'
            });
            expect(parser_util_1.analyzeDependence('{platform}element/element', '_e', options)).toEqual({
                source: 'platform/element/element.js',
                name: '_e',
                rawSource: '{platform}element/element',
                moduleType: 'javascript'
            });
            expect(parser_util_1.analyzeDependence('pro/platform/element/element', '_e', options)).toEqual({
                source: 'src/javascript/platform/element/element.js',
                name: '_e',
                rawSource: 'pro/platform/element/element',
                moduleType: 'javascript'
            });
            expect(parser_util_1.analyzeDependence('{pro}platform/element/element', '_e', options)).toEqual({
                source: 'src/javascript/platform/element/element.js',
                name: '_e',
                rawSource: '{pro}platform/element/element',
                moduleType: 'javascript'
            });
        });
    });
});
//# sourceMappingURL=parser.util.spec.js.map